; #INDEX# =======================================================================================================================
; Title .........: ACL
; AutoIt Version : 3.3.14.2
; Description ...: Call ACL functions from AutoIt
; Author(s) .....: NO1 :-)
; Exe ...........: cacls.exe
; ===============================================================================================================================

; #CONSTANTS# ===================================================================================================================
Global Const $ACL_EDIT_READ = "R"
Global Const $ACL_EDIT_WRITE = "C"
Global Const $ACL_EDIT_FULL = "F"
; ===============================================================================================================================


; #CURRENT# =====================================================================================================================
; _ACL_DisplayPermissions
; _ACL_EditPermissions
; _ACL_RevokeAllPermissions
; ===============================================================================================================================

; #FUNCTION# ====================================================================================================================
; Name...........: _ACL_DisplayPermissions
; Description ...: Displays all users and their permissions for a file or folder
; Syntax.........: _ACL_DisplayPermissions($sFileFolder)
; Parameters ....: $sFileFolder  Full path to a file or folder
; Return values .: Success      - Returns a message with all users and their permissions for a file or folder
;                  Failure      - 2: The file or folder doesn't exist (also sets @error to 2)
; Author ........: NO1 :-)
; Related .......: _ACL_EditPermissions, _ACL_RevokeAllPermissions
; Example .......: Yes
; ===============================================================================================================================
Func _ACL_DisplayPermissions($sFileFolder)
	If FileExists($sFileFolder) Then
		Local $sReturn
		$hPID = Run(@ComSpec & " /c icacls " & $sFileFolder, @HomeDrive & "\users\" & @UserName, @SW_HIDE, 0x2 + 0x4)
		While 1
			$sReturn &= StdoutRead($hPID)
			If @error Then ExitLoop
		WEnd
		Return $sReturn
	Else
		SetError(2)
		Return 2
	EndIf
EndFunc

; #FUNCTION# ====================================================================================================================
; Name...........: _ACL_EditPermissions
; Description ...: Edits the permissions for a file or folder for a specific user
; Syntax.........: _ACL_EditPermissions($sUser, $ePermission, $sDomain = @ComputerName)
; Parameters ....: $sFileFolder  Full path to a file or folder
;                : $sUser        The username of a user with a account in the domain
;                : $ePermission  $ACL_EDIT_READ: The user can read the file or contents of the given folder
;                                $ACL_EDIT_WRITE: The user can read, delete, write or change files or folders and their attributes
;                                $ACL_EDIT_FULL: The user can read, delete, write or change files or folders and their attributes
;                                                and furthermore edit or revoke their permissions
;                : $sDomain      The domain of the user account
; Return values .: Success      - Returns a message like "changes were successfull"
;                  Failure      - 2: The file or folder doesn't exist (also sets @error to 2)
; Author ........: NO1 :-)
; Related .......: _ACL_DisplayPermissions, _ACL_RevokeAllPermissions
; Example .......: Yes
; ===============================================================================================================================
Func _ACL_EditPermissions($sFileFolder, $sUser, $ePermission, $sDomain = @ComputerName)
	If FileExists($sFileFolder) Then
		Local $sReturn
		$hPID = Run('CACLS ' & $sFileFolder & ' /T /C /E /G ' & $sDomain & "\" & $sUser & ":" & $ePermission, @HomeDrive & "\users\" & @UserName, @SW_HIDE, 0x2 + 0x4)
		While 1
			$sReturn &= StdoutRead($hPID)
			If @error Then ExitLoop
		WEnd
		Return $sReturn
	Else
		SetError(2)
		Return 2
	EndIf
EndFunc

; #FUNCTION# ====================================================================================================================
; Name...........: _ACL_RevokeAllPermissions
; Description ...: Revokes the permissions for a file or folder for a specific user
; Syntax.........: _ACL_RevokeAllPermissions($sFileFolder, $sUser, $sDomain = @ComputerName)
; Parameters ....: $sFileFolder  Full path to a file or folder
;                : $sUser        The username of a user with a account in the domain
;                : $sDomain      The domain of the user account
; Return values .: Success      - Returns a message like "changes were successfull"
;                  Failure      - 2: The file or folder doesn't exist (also sets @error to 2)
; Author ........: NO1 :-)
; Related .......: _ACL_DisplayPermissions, _ACL_EditPermissions
; Example .......: Yes
; ===============================================================================================================================

Func _ACL_RevokeAllPermissions($sFileFolder, $sUser, $sDomain = @ComputerName)
	If FileExists($sFileFolder) Then
		Local $sReturn
		$hPID = Run('CACLS ' & $sFileFolder & ' /T /C /E /R ' & $sDomain & "\" & $sUser, @HomeDrive & "\users\" & @UserName, @SW_HIDE, 0x2 + 0x4)
		While 1
			$sReturn &= StdoutRead($hPID)
			If @error Then ExitLoop
		WEnd
		Return $sReturn
	Else
		SetError(2)
		Return 2
	EndIf
EndFunc